@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: dwmauth.cc 10617 2020-05-02 21:18:04Z dwm $
+// @(#) $Id: dwmauth.cc 10667 2020-05-03 18:51:46Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -54,7 +54,7 @@ extern "C" {
 #include "DwmSvnTag.hh"
 #include "DwmAuthPublicKeysFile.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/apps/dwmauth/dwmauth.cc 10617 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.1/apps/dwmauth/dwmauth.cc 10667 $");
 
 using namespace std;
 using namespace Dwm;
@@ -168,7 +168,7 @@ bool GenerateKeys(int argc, char *argv[])
       ofstream  os(pubFile.c_str());
       if (os) {
         string  &&pub64 = kp.Public().ToBase64String();
-        if (os << un << ' ' << pub64 << '\n') {
+        if (os << un << " dwm-ed25519 " << pub64 << '\n') {
           rc = true;
         }
         os.close();
