@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/src/DwmAuthEd25519Keys.cc 10618 $
-// @(#) $Id: DwmAuthEd25519Keys.cc 10618 2020-05-02 21:22:28Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.1/src/DwmAuthEd25519Keys.cc 10666 $
+// @(#) $Id: DwmAuthEd25519Keys.cc 10666 2020-05-03 18:50:48Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018, 2020
 //  All rights reserved.
@@ -251,7 +251,8 @@ namespace Dwm {
     {
       string  s;
       CryptoPP::StringSink  ssink(s);
-      this->DEREncode(ssink);
+      // this->DEREncode(ssink);
+      this->Save(ssink);
       return s;
     }
 
@@ -277,7 +278,8 @@ namespace Dwm {
       if (! s.empty()) {
         CryptoPP::StringSource  ssource(s, true);
         try {
-          this->BERDecode(ssource);
+          // this->BERDecode(ssource);
+          this->Load(ssource);
           rc = true;
         }
         catch (...) {
